formattools.report_component_format_contributions
=================================================

.. autofunction:: abjad.tools.formattools.report_component_format_contributions.report_component_format_contributions
   :noindex:
